implement more suggestions by lorenz schori
[project/uci.git] / uci.h
diff --git a/uci.h b/uci.h
index a4e3f96..b9b5cb3 100644 (file)
--- a/uci.h
+++ b/uci.h
@@ -60,14 +60,14 @@ struct uci_parse_context;
 
 
 /**
* uci_alloc: Allocate a new uci context
  */
-extern struct uci_context *uci_alloc(void);
+extern struct uci_context *uci_alloc_context(void);
 
 /**
* uci_free: Free the uci context including all of its data
  */
-extern void uci_free(struct uci_context *ctx);
+extern void uci_free_context(struct uci_context *ctx);
 
 /**
  * uci_perror: Print the last uci error that occured
@@ -60,14 +60,14 @@ struct uci_parse_context;
 
 /**
- * uci_alloc: Allocate a new uci context
+ * uci_alloc_context: Allocate a new uci context
  */
@@ -60,14 +60,14 @@ struct uci_parse_context;
 
 /**
- * uci_free: Free the uci context including all of its data
+ * uci_free_context: Free the uci context including all of its data
  */